/**
 * Copyright 2008 Bluestem Software LLC.  All Rights Reserved.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 */
package org.bluestemsoftware.open.eoa.ext.dependency.maven20.util;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.codehaus.plexus.util.StringUtils;

public class InterpolationHelper {

    private static final Pattern EXPRESSION_PATTERN = Pattern.compile("\\$\\{(env\\.)?([^}]+)\\}");

    private static final String EOA_SPEC_HOME_VAR = "${env.EOA_SPEC_HOME}";
    private static final String TRELEIS_HOME_VAR = "${env.TRELEIS_HOME}";
    
    public static String interpolate(String input){
        
        String result = input;
        
        // poms for eoa extension artifacts use the eoa_spec_home
        // variable which we replace with treleis home which is
        // set by treleis start up script, i.e. the end user will
        // not have eoa_spec_home set
        
        if (result.contains(EOA_SPEC_HOME_VAR)) {
            if (System.getProperty("EOA_SPEC_HOME") == null) {
                if (System.getProperty("TRELEIS_HOME") != null) {
                    result.replace(EOA_SPEC_HOME_VAR, TRELEIS_HOME_VAR);
                }
            }
        }
        
        Matcher matcher = EXPRESSION_PATTERN.matcher(result);
        
        if (matcher.find()) {
            String variable = matcher.group(0);
            String prefix = matcher.group(1);
            String env = matcher.group(2);
            prefix = prefix == null ? "" : prefix;
            Object value = System.getenv(env);
            if (value != null) {
                result = StringUtils.replace(result, variable, value.toString());
                matcher.reset(result);
            } else {
                throw new IllegalArgumentException("Failed to replace variable "
                        + variable
                        + " within the following pom: "
                        + System.getProperty("line.separator")
                        + input);
            }
        }
        
        return result;
        
    }

}
